"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const mdast_util_to_string_1 = __importDefault(require("mdast-util-to-string"));
const github_slugger_1 = __importDefault(require("github-slugger"));
const permalinkIconAst_1 = __importDefault(require("./permalinkIconAst"));
const ABSOLUTE_URL = /^(https?:\/\/|\/\/)/i;
// The headers will be updated to include a link to their hash
const HEADINGS = ['h2', 'h3', 'h4', 'h5', 'h6'];
function rehypeDocs({ filePath, tag, processor }) {
    const slugger = new github_slugger_1.default();
    const anchorSlugger = new github_slugger_1.default();
    function visitAnchor(node) {
        const props = node.properties;
        const href = props === null || props === void 0 ? void 0 : props.href;
        if (!href)
            return;
        if (props.href === href) {
            const isAbsoluteUrl = ABSOLUTE_URL.test(href);
            // const isHash = href[0] === '#';
            // const isRepoUrl = !isHash;
            if (isAbsoluteUrl) {
                props.className = 'absolute';
                props.target = '_blank';
                props.rel = 'noopener noreferrer';
                return;
            }
        }
        const [relativePath, hash] = props.href.split('#');
        // Reset the slugger because single pages can have multiple urls to the same hash
        anchorSlugger.reset();
        // The URL is relative at this point
        props.className = 'relative';
        // Update the hash used by anchors to match the one set for headers
        props.href = hash
            ? `${relativePath}#${anchorSlugger.slug(hash)}`
            : relativePath;
    }
    function visitHeading(node) {
        const text = mdast_util_to_string_1.default(node);
        if (!text)
            return;
        const id = slugger.slug(text);
        node.properties.className = 'heading';
        node.children = [
            {
                type: 'element',
                tagName: 'span',
                properties: { id },
            },
            {
                type: 'element',
                tagName: 'a',
                properties: {
                    href: `#${id}`,
                },
                children: node.children,
            },
            {
                type: 'element',
                tagName: 'span',
                properties: { className: 'permalink' },
                children: [permalinkIconAst_1.default],
            },
        ];
    }
    return function transformer(tree) {
        unist_util_visit_1.default(tree, (node) => node.tagName === 'a', visitAnchor);
        unist_util_visit_1.default(tree, (node) => HEADINGS.includes(node.tagName), visitHeading);
    };
}
exports.default = rehypeDocs;
//# sourceMappingURL=rehypeDocs.js.map