"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = require("path");
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const path_2 = __importDefault(require("path"));
function rehypeDocs({ filePath, tag, processor }) {
    function visitInlineCode(node) {
        const value = node.value;
        if (value.startsWith('markdown:')) {
            const file = value.substr(9);
            const combinedPath = path_2.default.normalize(path_1.dirname(filePath) + '/' + file);
            if (!fs_1.default.existsSync(combinedPath)) {
                throw Error(`Invalid fragment specified; no such file "${combinedPath}"`);
            }
            const code = fs_1.default.readFileSync(combinedPath, 'utf8');
            const markdown = processor();
            try {
                node.value = `<div class=\"markdown-fragment\">${markdown.processSync(code)}</div>`;
                node.type = 'html';
            }
            catch (e) {
                throw Error(`${e.message} \nFile: ${file}`);
            }
        }
    }
    function visitLink(node) {
        if (node.children.length > 0 && node.children[0].value === '!embed') {
            const file = node.url;
            const path = path_1.dirname(filePath) + '/' + file;
            if (!fs_1.default.existsSync(path)) {
                throw Error(`Invalid fragment specified; no such file "${path}"`);
            }
            const code = fs_1.default.readFileSync(path, 'utf8');
            const markdown = processor();
            try {
                node.value = `<div class=\"markdown-fragment\">${markdown.processSync(code)}</div>`;
                node.type = 'html';
            }
            catch (e) {
                throw Error(`${e.message} \nFile: ${file}`);
            }
        }
        if (node.children.length > 0 && node.children[0].value.indexOf('%') === 0) {
            node.value = `
      <div class="card card-bordered bg-soft-info">
        <div class="card-body">
        <h5 class="card-title">${node.children[0].value.substring(1)}</h5>
          <div class="card-text">
            <div class="embed-responsive embed-responsive-16by9">
              <iframe class="embed-responsive-item" src="${node.url}" allowfullscreen></iframe>
            </div>
          </div>
        </div>
      </div>`;
            // node.value = `<iframe
            //   width="560"
            //   height="315"
            //   src="${node.url}"
            //   frameborder="0"
            //   allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
            //   allowfullscreen>
            // </iframe>`;
            node.type = 'html';
        }
    }
    return function transformer(tree) {
        unist_util_visit_1.default(tree, 'inlineCode', visitInlineCode);
        unist_util_visit_1.default(tree, (node) => node.type === 'link', visitLink);
        return tree;
    };
}
exports.default = rehypeDocs;
//# sourceMappingURL=rehypeMarkdownToHtml.js.map